#!/bin/bash

#####################################################################################################
# DISABLE IPV6 AS GRUB KERNEL PARAMETERS
#####################################################################################################

#      :
# (     " ",    (  : http://php.su/articles/?cat=regexp&page=001 )
#
# REGEXP  '[ \t]*'   '[ \t]{0,}'  SED     ( -    )
# REGEXP  '[ \t]+'   '[ \t]{1,}'  SED     (    )
#
#  '^[ \t]*linux'         ,   ,     'linux'
#  'linux[ \t]+\/' :  'linux'         '/' ()
#
#  '^[ \t]*kernel[ \t]+\/'      'linux /',  
#          
#    'linux'   '/'     
#
#  . (   []):
# '^'   , ,     (,  ,    )
# '$'    , ,     (,  ,    )


# grub-legacy (grub1)
for file in /boot/grub/*.lst /boot/grub/*.mnu /boot/grub/*.cfg ; do
        fulname="$(dirname $file)"/"$(basename $file)"
        if [ -f "$fulname" ] ; then
                #     disable.ipv6=0
                #     disable.ipv6=1
                #   (  )   'linux /'  'kernel /'
                #     '$'  ' disable.ipv6=1'
                #  
                #               < >linux< >/<-->
                #                  < >kernel< >/<-->
                #            < >linux< >/<-->disable.ipv6=1
                #                       < >kernel< >/<-->disable.ipv6=1
                sed "/disable.ipv6/s/disable.ipv6=1//gI;/disable.ipv6/s/disable.ipv6=0//gI;/^[ \t]*linux[ \t]+\//s/$/ disable.ipv6=1/I;/^[ \t]*kernel[ \t]+\//s/$/ disable.ipv6=1/I" $fulname > "$fulname".new
                #    ""    
	        if [ ! -f "$fulname".original ] ; then
        	        cp $fulname "$fulname".original
	        fi
                mv "$fulname".new "$fulname"
        fi
done

# pc-grub (grub2)
#  disable.ipv6=1       (GRUB_CMDLINE_LINUX=...)
#      : https://help.ubuntu.com/community/Grub2
fulname=/etc/default/grub
if [ -f "$fulname" ] ; then
        #     disable.ipv6=0
        #     disable.ipv6=1
        #   (  )   'GRUB_CMDLINE_LINUX='
        #     '"'  '"disable.ipv6=1 '
        #  
        #                     GRUB_CMDLINE_LINUX="<    >"
        #            GRUB_CMDLINE_LINUX="disable.ipv6=1 <    >"
        sed "/disable.ipv6/s/disable.ipv6=1//gI;/disable.ipv6/s/disable.ipv6=0//gI;/^[ \t]*GRUB_CMDLINE_LINUX[ \t]*=/s/\"/\"disable.ipv6=1 /I"  $fulname > "$fulname".new
        if [ ! -f "$fulname".original ] ; then
       	        cp $fulname "$fulname".original
        fi
        mv "$fulname".new "$fulname"
elif [ -d /etc/default ] ; then
        #   ,      
        echo GRUB_CMDLINE_LINUX="disable.ipv6=1" > $fulname
fi

#   GRUB ( ,   grub1)
#/boot/grub/*.cfg
#/boot/grub/*.lst
#/boot/grub/*.mnu
# if grub1 - may be error, ignore errors...
update-grub 2> /dev/null

#####################################################################################################
# DISABLE IPV6 AS MODULE LOADING
# DISABLE IPV6 IN SYSCTL PARAMETERS
#####################################################################################################

#     .conf,       .conf
#    
# /etc/sysctl		/etc/modprobe
# /etc/sysctl.conf	/etc/modprobe.conf
# /etc/sysctl.d/*	/etc/modprobe.d/*

for typeofconf in modprobe sysctl ; do

	myfile=/etc/$typeofconf".d/zzzzz-kos-disable-ipv6.conf
	myexist=0
	for file in /etc/"$typeofconf" /etc/"$typeofconf".conf ; do
    
	        fulname="$(dirname $file)"/"$(basename $file)"

		if [ "$fulname" = "$myfile" ] ; then
			myexist=1

		#      
		elif [ -f "$fulname" ] ; then

			if [ "modprobe" = "$typeofconf" ] ; then
				#    'alias net-pf-10'     '#alias net-pf-10'
				sed '/^[ \t]*alias[ \t]+net-pf-10/s/alias/#alias/I'  "$fulname" > "$fulname".new
				sed '/^[ \t]*alias[ \t]+ipv6/s/alias/#alias/I'  "$fulname" > "$fulname".new

				#      
				echo #KOS:) disabling ipv6	| tee -a "$fulname".new
       				echo blacklist net-pf-10	| tee -a "$fulname".new
			        echo blacklist ipv6		| tee -a "$fulname".new
			else
				#    'net.ipv6.conf.*.disable_ipv6'     '#net.ipv6.conf.*.disable_ipv6'
				sed '/^[ \t]*net.ipv6.conf.[a-z]*.disable_ipv6/s/net.ipv6.conf/#net.ipv6.conf/I'  "$fulname" > "$fulname".new

				echo #KOS:) disabling ipv6        		| tee -a "$fulname".new
				echo net.ipv6.conf.all.disable_ipv6=1    	| tee -a "$fulname".new
				echo net.ipv6.conf.default.disable_ipv6=1    	| tee -a "$fulname".new
				echo net.ipv6.conf.lo.disable_ipv6=1    	| tee -a "$fulname".new
			fi

			#    
		        if [ ! -f "$fulname".original ] ; then
        		        cp $fulname "$fulname".original
		        fi
			mv "$fulname".new "$fulname"
		fi
	done
	if [ myexist=0] ; then
		if [ -d /etc/"$typeofconf".d ] ; then
			if [ "modprobe" = "$typeofconf" ] ; then
				#      
				echo #KOS:) disabling ipv6	| tee -a "$myfile"
				echo blacklist net-pf-10	| tee -a "$myfile"
				echo blacklist ipv6		| tee -a "$myfile"
			else
				echo #KOS:) disabling ipv6        		| tee -a "$myfile"
				echo net.ipv6.conf.all.disable_ipv6=1    	| tee -a "$myfile"
				echo net.ipv6.conf.default.disable_ipv6=1    	| tee -a "$myfile"
				echo net.ipv6.conf.lo.disable_ipv6=1    	| tee -a "$myfile"
			fi
		fi
	fi
done

#####################################################################################################
# DISABLE IPV6 AS INIT SYSV USER-SCRIPT
#####################################################################################################

#   
# /etc/rc.local
# /etc/rc*.d/*rc.local

for file in /etc/rc.local /etc/rc*.d/*rc.local ; do
    
	fulname="$(dirname $file)"/"$(basename $file)"

	#    'exit 0'     ''
	sed '/^[ \t]*exit[ \t]+0/s/exit/#exit/I'  "$fulname" > "$fulname".new

	#     

	echo #KOS:) disabling ipv6					| tee -a "$fulname".new
	echo if [ -d /proc/sys/net/ipv6 ] ; then			| tee -a "$fulname".new
	#  
	#echo 1 | tee /proc/sys/net/ipv6/conf/all/disable_ipv6
	#echo 1 | tee /proc/sys/net/ipv6/conf/default/disable_ipv6
	#echo 1 | tee /proc/sys/net/ipv6/conf/lo/disable_ipv6
	#  
	echo     /sbin/sysctl -w net.ipv6.conf.all.disable_ipv6=1	| tee -a "$fulname".new
	echo     /sbin/sysctl -w net.ipv6.conf.default.disable_ipv6=1	| tee -a "$fulname".new
	echo     /sbin/sysctl -w net.ipv6.conf.lo.disable_ipv6=1	| tee -a "$fulname".new
	echo fi								| tee -a "$fulname".new
	echo exit 0							| tee -a "$fulname".new

	#    
        if [ ! -f "$fulname".original ] ; then
       	        cp $fulname "$fulname".original
        fi
	mv "$fulname".new "$fulname"

	#    ,     *rc.local   "Executable"   
	# ( Ubuntu bug #50093,  2006  , . https://bugs.launchpad.net/ubuntu/+source/procps/+bug/50093 )
	#   

	chmod 755 "$fulname"

done


